@@ -8,4 +8,4 @@ class TableEnum(Enum):
     数据库表枚举信息示例
     """
 
-    aritle_list_table = {"value": "article_info_list", "notes": "项目列表信息", "demand_code": "DemoSpider_aritle_list_table_demand_code"}
+    article_list_table = {"value": "article_info_list", "notes": "项目列表信息", "demand_code": "DemoSpider_article_list_table_demand_code"}
